clear all
close all

%% Initialisation
a5sphere
pid

%%

omega_naa = 0.01667;
t = 1:1:200;
t = t'
water_level = sin(t/9)
for i=1:200
    water_level(i,1) = water_level(i,1)*H_F(i,1)
end
hyd_buoyancyforce = [t water_level]


%% For Simulink
C_ct = eye(6);
Cr = [1 1 1 1];
D_ct = [0 0 0 0 0 0]';


%% For Matlab
Cct = [1 0 0 0 0 0;
       0 1 0 0 0 0;
       0 0 1 1 1 1];
Dct = [0 0 0]';

%% Damping and spring for wave dynamics block
K = 8800; %3032;
C = 1000; %126230;
totalmass = m+m_inf

%% Radiation force estimator
% Ar = par.Ar;
% Br = par.Br;
% Cr = par.Cr;
% Dr = par.Dr;
C_b = Asys(1,2)*(1+(m_inf/m));

 

sys = ss(Asys,Bsysu,Cct,Dct);
set(sys, 'inputname', {'Machinary force'},...
         'outputname', {'Velocity of motion p' 'Vertical disp. \eta' 'Radiation force'},...
         'statename', {'p' 'eta' 'z1' 'z2' 'z3' 'z4'});
transfer = tf(sys,1)

%% PID control
Kp = 0;
Ki = 1.5;
Kd = 0;
num = [0.6689 2.394 5.018 4.499 2.067+Kd (6.882e-016)+Kp]
den = [1 3.58 9.713 14.7 18.63 13.23+Kd 6.082+Kp]
t = 0:0.01:50;
step(num,den,t)
     
%% Stability analysis

%Eigenvalues and eigenvector matrix
[Eig,M] = eig(single(Asys));
E = eig(Asys);
Ename = 'Eigenvalues';

% Controllabilty matrix H and controllability Gramian. 
H = M^(-1)*Bsysu
Hc = ctrb(Asys,Bsysd)
Gramian = gram(Asys,Bsysd)
H_rank = rank(Hc)


% Observability matrix F, the system is observable
O = obsv(Asys,Cct)
O_rank = rank(obsv(Asys,Cct))

%Transition matrix
dt = 0.03;
PHI = expm(Asys*dt);

%% F?lgeforhold Avviksforhold
s = tf('s')
d= (s*eye(6)-Asys)^(-1)
hu = Cct*d*Bsysu
hv = Cct*d*Bsysd
M = hu*hr/(1+hu*hr)
N = 1/(1+hu*hr)

%% RGA matrix and singular value decomposition
RGA = Asys.*pinv(Asys)
[U,S,V] = svd(Asys)
    
clf
t = 0:0.01:4;
u = sin(10*t);
lsim(sys,u,t)      

%% Ziegler-Nichols tuning
% 
[MAG,PHASE,W] = nichols(sys)
[MAGB,PHASEB] = bode(sys)
bode(sys)

plotting(sys);



k = 1;
cl31 = feedback(sys13,-k);

impulseplot(sys13,'b--',cl31,'r')
legend('open loop','closed loop',4)

cloop = feedback(sys,-k,1,1);
impulseplot(sys,'b--',cloop,'r',5)  




